@@ -1,6 +1,6 @@
 #  fixtures: Fixtures with cleanups for testing and convenience.
 #
-# Copyright (c) 2010, Robert Collins <robertc@robertcollins.net>
+# Copyright (c) 2010, 2011, Robert Collins <robertc@robertcollins.net>
 # 
 # Licensed under either the Apache License, Version 2.0 or the BSD 3-clause
 # license at the users choice. A copy of both licenses are available in the
@@ -17,20 +17,58 @@
 """Included fixtures."""
 
 __all__ = [
+    'ByteStream',
+    'DetailStream',
+    'EnvironmentVariable',
     'EnvironmentVariableFixture',
+    'FakeLogger',
+    'FakePopen',
+    'LoggerFixture',
+    'LogHandler',
     'MonkeyPatch',
+    'NestedTempfile',
     'PackagePathEntry',
     'PopenFixture',
     'PythonPackage',
     'PythonPathEntry',
+    'StringStream',
     'TempDir',
+    'TempHomeDir',
+    'Timeout',
+    'TimeoutException',
     ]
 
 
-from fixtures._fixtures.environ import EnvironmentVariableFixture
+from fixtures._fixtures.environ import (
+    EnvironmentVariable,
+    EnvironmentVariableFixture,
+    )
+from fixtures._fixtures.logger import (
+    FakeLogger,
+    LoggerFixture,
+    LogHandler,
+    )
 from fixtures._fixtures.monkeypatch import MonkeyPatch
-from fixtures._fixtures.popen import PopenFixture
+from fixtures._fixtures.popen import (
+    FakePopen,
+    PopenFixture,
+    )
 from fixtures._fixtures.packagepath import PackagePathEntry
 from fixtures._fixtures.pythonpackage import PythonPackage
 from fixtures._fixtures.pythonpath import PythonPathEntry
-from fixtures._fixtures.tempdir import TempDir
+from fixtures._fixtures.streams import (
+    ByteStream,
+    DetailStream,
+    StringStream,
+    )
+from fixtures._fixtures.tempdir import (
+    NestedTempfile,
+    TempDir,
+    )
+from fixtures._fixtures.temphomedir import (
+    TempHomeDir,
+    )
+from fixtures._fixtures.timeout import (
+    Timeout,
+    TimeoutException,
+    )
