@@ -1,12 +1,12 @@
 #  fixtures: Fixtures with cleanups for testing and convenience.
 #
 # Copyright (c) 2010, Robert Collins <robertc@robertcollins.net>
-# 
+#
 # Licensed under either the Apache License, Version 2.0 or the BSD 3-clause
 # license at the users choice. A copy of both licenses are available in the
 # project source as Apache-2.0 and BSD. You may not use this file except in
 # compliance with one of these two licences.
-# 
+#
 # Unless required by applicable law or agreed to in writing, software
 # distributed under these licenses is distributed on an "AS IS" BASIS, WITHOUT
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
@@ -23,13 +23,17 @@ __all__ = [
 import itertools
 import sys
 
+from testtools.compat import (
+    advance_iterator,
+    reraise,
+    )
 from testtools.helpers import try_import
 
-class MultipleExceptions(Exception):
-    """Report multiple exc_info tuples in self.args."""
-
-MultipleExceptions = try_import(
-    "testtools.MultipleExceptions", MultipleExceptions)
+from fixtures.callmany import (
+    CallMany,
+    # Deprecated, imported for compatibility.
+    MultipleExceptions,
+    )
 
 gather_details = try_import("testtools.testcase.gather_details")
 
@@ -70,7 +74,7 @@ class Fixture(object):
         :param kwargs: Keyword args for cleanup.
         :return: None
         """
-        self._cleanups.append((cleanup, args, kwargs))
+        self._cleanups.push(cleanup, *args, **kwargs)
 
     def addDetail(self, name, content_object):
         """Add a detail to the Fixture.
@@ -104,22 +108,10 @@ class Fixture(object):
         :return: A list of the exc_info() for each exception that occured if
             raise_first was False
         """
-        cleanups = reversed(self._cleanups)
-        self._clear_cleanups()
-        result = []
-        for cleanup, args, kwargs in cleanups:
-            try:
-                cleanup(*args, **kwargs)
-            except Exception:
-                result.append(sys.exc_info())
-        if result and raise_first:
-            if 1 == len(result):
-                error = result[0]
-                raise error[0], error[1], error[2]
-            else:
-                raise MultipleExceptions(*result)
-        if not raise_first:
-            return result
+        try:
+            return self._cleanups(raise_errors=raise_first)
+        finally:
+            self._clear_cleanups()
 
     def _clear_cleanups(self):
         """Clean the cleanup queue without running them.
@@ -130,7 +122,7 @@ class Fixture(object):
 
         This also clears the details dict.
         """
-        self._cleanups = []
+        self._cleanups = CallMany()
         self._details = {}
         self._detail_sources = []
 
@@ -139,7 +131,10 @@ class Fixture(object):
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        errors = self.cleanUp()
+        try:
+            self._cleanups()
+        finally:
+            self._clear_cleanups()
         return False # propogate exceptions from the with body.
 
     def getDetails(self):
@@ -147,7 +142,7 @@ class Fixture(object):
 
         This does not return the internal dictionary: mutating it will have no
         effect. If you need to mutate it, just do so directly.
-        
+
         :return: Dict from name -> content_object.
         """
         result = dict(self._details)
@@ -159,7 +154,7 @@ class Fixture(object):
         """Prepare the Fixture for use.
 
         This should be overridden by most concrete fixtures. When overriding
-        be sure to include self.addCleanup calls to restore the fixture to 
+        be sure to include self.addCleanup calls to restore the fixture to
         an un-setUp state, so that a single Fixture instance can be reused.
 
         After setUp is called, the fixture will have one or more attributes
@@ -199,7 +194,7 @@ class Fixture(object):
             # The child failed to come up, capture any details it has (copying
             # the content, it may go away anytime).
             if gather_details is not None:
-                gather_details(fixture, self)
+                gather_details(fixture.getDetails(), self._details)
             raise
         else:
             self.addCleanup(fixture.cleanUp)
@@ -214,7 +209,7 @@ class FunctionFixture(Fixture):
 
     Typically used when an existing object or function interface exists but you
     wish to use it as a Fixture (e.g. because fixtures are in use in your test
-    suite and this will fit in better). 
+    suite and this will fit in better).
 
     To adapt an object with differently named setUp and cleanUp methods:
     fixture = FunctionFixture(object.install, object.__class__.remove)
