@@ -13,7 +13,6 @@
 # license you chose for the specific language governing permissions and
 # limitations under that license.
 
-import sys
 import types
 
 import testtools
@@ -29,6 +28,8 @@ require_gather_details = skipIf(gather_details is None,
         "gather_details() is not available.")
 
 
+# Note: the cleanup related tests are strictly speaking redundant, IFF they are
+# replaced with contract tests for correct use of CallMany.
 class TestFixture(testtools.TestCase):
 
     def test_resetCallsSetUpCleanUp(self):
@@ -102,7 +103,7 @@ class TestFixture(testtools.TestCase):
                 self.addCleanup(raise_exception2)
                 self.addCleanup(raise_exception1)
         fixture = FixtureWithException()
-        ctx = fixture.__enter__()
+        fixture.__enter__()
         exc = self.assertRaises(Exception, fixture.__exit__, None, None, None)
         self.assertEqual(('woo',), exc.args[0][1].args)
         self.assertEqual(('hoo',), exc.args[1][1].args)
@@ -163,6 +164,18 @@ class TestFixture(testtools.TestCase):
             child.addDetail('foo', 'content')
         self.assertEqual({}, parent.getDetails())
 
+    def test_duplicate_details_are_disambiguated(self):
+        parent = fixtures.Fixture()
+        with parent:
+            parent.addDetail('foo', 'parent-content')
+            child = fixtures.Fixture()
+            parent.useFixture(child)
+            # Note that we add the detail *after* using the fixture: the parent
+            # has to query just-in-time.
+            child.addDetail('foo', 'child-content')
+            self.assertEqual({'foo': 'parent-content',
+                              'foo-1': 'child-content',}, parent.getDetails())
+
     def test_addDetail(self):
         fixture = fixtures.Fixture()
         with fixture:
